@@ -1,7 +1,6 @@
-use k8s_openapi::{api::batch::v1::CronJob, chrono::Utc};
-
 use async_trait::async_trait;
-use tui::{
+use k8s_openapi::{api::batch::v1::CronJob, chrono::Utc};
+use ratatui::{
   backend::Backend,
   layout::{Constraint, Rect},
   widgets::{Cell, Row},
@@ -63,6 +62,9 @@ impl From<CronJob> for KubeCronJob {
 }
 
 impl KubeResource<CronJob> for KubeCronJob {
+  fn get_name(&self) -> &String {
+    &self.name
+  }
   fn get_k8s_obj(&self) -> &CronJob {
     &self.k8s_obj
   }
@@ -138,6 +140,7 @@ fn draw_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
     },
     app.light_theme,
     app.is_loading,
+    app.data.selected.filter.to_owned(),
   );
 }
 
