@@ -1,7 +1,6 @@
-use k8s_openapi::{api::apps::v1::Deployment, chrono::Utc};
-
 use async_trait::async_trait;
-use tui::{
+use k8s_openapi::{api::apps::v1::Deployment, chrono::Utc};
+use ratatui::{
   backend::Backend,
   layout::{Constraint, Rect},
   widgets::{Cell, Row},
@@ -60,6 +59,9 @@ impl From<Deployment> for KubeDeployment {
 }
 
 impl KubeResource<Deployment> for KubeDeployment {
+  fn get_name(&self) -> &String {
+    &self.name
+  }
   fn get_k8s_obj(&self) -> &Deployment {
     &self.k8s_obj
   }
@@ -132,6 +134,7 @@ fn draw_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
     },
     app.light_theme,
     app.is_loading,
+    app.data.selected.filter.to_owned(),
   );
 }
 
