@@ -1,3 +1,5 @@
+use anyhow::anyhow;
+use async_trait::async_trait;
 use k8s_openapi::{
   api::core::v1::{Node, Pod},
   chrono::Utc,
@@ -7,16 +9,13 @@ use kube::{
   core::ListMeta,
   Api,
 };
-use tokio::sync::MutexGuard;
-
-use anyhow::anyhow;
-use async_trait::async_trait;
-use tui::{
+use ratatui::{
   backend::Backend,
   layout::{Constraint, Rect},
   widgets::{Cell, Row},
   Frame,
 };
+use tokio::sync::MutexGuard;
 
 use super::{
   metrics::{self, KubeNodeMetrics},
@@ -175,6 +174,9 @@ impl KubeNode {
 }
 
 impl KubeResource<Node> for KubeNode {
+  fn get_name(&self) -> &String {
+    &self.name
+  }
   fn get_k8s_obj(&self) -> &Node {
     &self.k8s_obj
   }
@@ -317,6 +319,7 @@ fn draw_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
     },
     app.light_theme,
     app.is_loading,
+    app.data.selected.filter.to_owned(),
   );
 }
 
