@@ -1,9 +1,8 @@
+use async_trait::async_trait;
 use k8s_openapi::{
   api::core::v1::PersistentVolumeClaim, apimachinery::pkg::api::resource::Quantity, chrono::Utc,
 };
-
-use async_trait::async_trait;
-use tui::{
+use ratatui::{
   backend::Backend,
   layout::{Constraint, Rect},
   widgets::{Cell, Row},
@@ -85,6 +84,9 @@ impl From<PersistentVolumeClaim> for KubePVC {
 }
 
 impl KubeResource<PersistentVolumeClaim> for KubePVC {
+  fn get_name(&self) -> &String {
+    &self.name
+  }
   fn get_k8s_obj(&self) -> &PersistentVolumeClaim {
     &self.k8s_obj
   }
@@ -166,6 +168,7 @@ fn draw_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
     },
     app.light_theme,
     app.is_loading,
+    app.data.selected.filter.to_owned(),
   );
 }
 
