@@ -1,7 +1,6 @@
-use k8s_openapi::{api::storage::v1::StorageClass, chrono::Utc};
-
 use async_trait::async_trait;
-use tui::{
+use k8s_openapi::{api::storage::v1::StorageClass, chrono::Utc};
+use ratatui::{
   backend::Backend,
   layout::{Constraint, Rect},
   widgets::{Cell, Row},
@@ -55,6 +54,9 @@ impl From<StorageClass> for KubeStorageClass {
 }
 
 impl KubeResource<StorageClass> for KubeStorageClass {
+  fn get_name(&self) -> &String {
+    &self.name
+  }
   fn get_k8s_obj(&self) -> &StorageClass {
     &self.k8s_obj
   }
@@ -131,6 +133,7 @@ fn draw_block<B: Backend>(f: &mut Frame<'_, B>, app: &mut App, area: Rect) {
     },
     app.light_theme,
     app.is_loading,
+    app.data.selected.filter.to_owned(),
   );
 }
 
